@@ -30,7 +30,7 @@ use Locale::Maketext::Simple    Class => 'CPANPLUS', Style => 'gettext';
 
 local $Params::Check::VERBOSE = 1;
 
-$VERSION = '0.35_03';
+$VERSION = '0.41_01';
 
 =pod
 
@@ -375,47 +375,52 @@ sub _find_prereqs {
 
     my $prereqs = {};
 
-    my $safe_ver = version->new('0.31_03');
-
-    my $content;
-
-    if ( version->new( $Module::Build::VERSION ) >= $safe_ver and IPC::Cmd->can_capture_buffer ) {
-        my @buildflags = $dist->_buildflags_as_list( $buildflags );
-
-        # Use the new Build action 'prereq_data'
-        my $run_perl    = $conf->get_program('perlwrapper');
-
-        unless ( scalar run(    command => [$perl, $run_perl, BUILD->($dir), 'prereq_data', @buildflags],
-                                buffer  => \$content,
-                                verbose => 0 ) 
-        ) {
-            error( loc( "Build 'prereq_data' failed: %1 %2", $!, $content ) );
-            return;
-        }
+    $prereqs = $dist->find_mymeta_requires()
+       if $dist->can('find_mymeta_requires');
 
+    if ( keys %$prereqs ) {
+        # Ugly hack
     }
     else {
-        my $file = File::Spec->catfile( $dir, '_build', 'prereqs' );
-        return unless -f $file;
+      my $safe_ver = version->new('0.31_03');
+      my $content;
+      if ( version->new( $Module::Build::VERSION ) >= $safe_ver and IPC::Cmd->can_capture_buffer ) {
+          my @buildflags = $dist->_buildflags_as_list( $buildflags );
 
-        my $fh = FileHandle->new();
+          # Use the new Build action 'prereq_data'
+          my $run_perl    = $conf->get_program('perlwrapper');
+
+          unless ( scalar run(    command => [$perl, $run_perl, BUILD->($dir), 'prereq_data', @buildflags],
+                                buffer  => \$content,
+                                verbose => 0 ) 
+          ) {
+            error( loc( "Build 'prereq_data' failed: %1 %2", $!, $content ) );
+            return;
+          }
 
-        unless( $fh->open( $file ) ) {
-           error( loc( "Cannot open '%1': %2", $file, $! ) );
-           return;
         }
+        else {
+          my $file = File::Spec->catfile( $dir, '_build', 'prereqs' );
+          return unless -f $file;
+
+          my $fh = FileHandle->new();
+
+          unless( $fh->open( $file ) ) {
+            error( loc( "Cannot open '%1': %2", $file, $! ) );
+            return;
+          }
         
-        $content = do { local $/; <$fh> };
-    }
+          $content = do { local $/; <$fh> };
+        }
 
-    return unless $content;
-    my $bphash = eval $content;
-    return unless $bphash and ref $bphash eq 'HASH';
-    foreach my $type ('requires', 'build_requires') {
-       next unless $bphash->{$type} and ref $bphash->{$type} eq 'HASH';
-       $prereqs->{$_} = $bphash->{$type}->{$_} for keys %{ $bphash->{$type} };
+        return unless $content;
+        my $bphash = eval $content;
+        return unless $bphash and ref $bphash eq 'HASH';
+        foreach my $type ('requires', 'build_requires') {
+          next unless $bphash->{$type} and ref $bphash->{$type} eq 'HASH';
+          $prereqs->{$_} = $bphash->{$type}->{$_} for keys %{ $bphash->{$type} };
+        }
     }
-
     # Temporary fix
     delete $prereqs->{'perl'};
 
@@ -636,7 +641,8 @@ sub create {
 
             } 
             else {
-                msg( $test_output, 0 );
+                msg( loc( "MAKE TEST passed:\n%1", $test_output ), 0 );
+                #msg( $test_output, 0 );
                 $dist->status->test(1);
             }
         } 
@@ -688,13 +694,15 @@ sub install {
     my %hash = @_;
 
     
-    my $verbose; my $perl; my $force;
+    my $verbose; my $perl; my $force; my $buildflags;
     {   local $Params::Check::ALLOW_UNKNOWN = 1;
         my $tmpl = {
             verbose => { default => $conf->get_conf('verbose'),
                          store   => \$verbose },
             force   => { default => $conf->get_conf('force'),
                          store   => \$force },
+            buildflags => { default => $conf->get_conf('buildflags'),
+                            store   => \$buildflags },
             perl    => { default => $^X, store   => \$perl },
         };
     
@@ -725,7 +733,7 @@ sub install {
     }
 
     my $fail;
-    my @buildflags = $dist->_buildflags_as_list( $dist->status->_buildflags );
+    my @buildflags = $dist->_buildflags_as_list( $buildflags );
     my $run_perl    = $conf->get_program('perlwrapper');
 
     ### hmm, how is this going to deal with sudo?
@@ -811,7 +819,7 @@ terms as Perl itself.
 
 =cut
 
-1;
+qq[Putting the Module::Build into CPANPLUS];
 
 
 # Local variables:
